@@ -1,8 +1,8 @@
 import os
 import sys
+import glob
 import collections.abc
-sys.path.append(os.getcwd())
-sys.path.append(os.getcwd()+"/configenv")
+
 
 class ConfigEnv:
     def __init__(self) -> None:
@@ -36,17 +36,30 @@ class ConfigEnv:
                 config.update({key: os.getenv(value)})
         return config
 
+    def __get_path_files(self):
+        result =[]
+        sys_paths = sys.path
+        for sys_path in sys_paths:
+            try:
+                dir = sys_path+"/configenv"
+                os.chdir(dir)
+                for file in glob.glob("*.json"):
+                    result.append(dir+"/"+file)
+                break
+            except:
+                continue                
+        return result
+
     def __run(self):
+        files_path = self.__get_path_files()
+        files = [i.split('/')[-1] for i in files_path]
         self.config = {}
-        dir = os.getcwd() + "/configenv"
-        files = os.listdir(dir)
         filenames = []
-        for file in files:
-            path = dir + "/" +file
-            if os.stat(path).st_size != 0:
+        for file, file_path in zip(files, files_path) :
+            if os.stat(file_path).st_size != 0:
                 filename = file.split(".")[0].replace("-", "_") + "_config"
                 filenames.append(filename)
-                exec(filename + "= eval(open(path).read())")
+                exec(filename + "= eval(open(file_path).read())")
 
         if self.python_env == None or "DEFAULT":
             if "default.json" in files:
